@@ -13,7 +13,8 @@
 # limitations under the License.
 
 import pytest
-from picosvg.svg_types import SVGPath, Rect
+from picosvg.svg_transform import Affine2D
+from picosvg.svg_types import SVGPath, SVGRect, Rect
 from svg_test_helpers import *
 
 
@@ -143,3 +144,37 @@ def test_arcs_to_cubics(path, expected_result):
     print(f"A: {actual}")
     print(f"E: {expected_result}")
     assert actual == expected_result
+
+
+@pytest.mark.parametrize(
+    "path, transform, expected_result",
+    [
+        # translate
+        (
+            "M1,1 L2,1 L2,2 L1,2 Z",
+            Affine2D.identity().translate(2, 1),
+            "M3,2 L4,2 L4,3 L3,3 Z",
+        ),
+        # same shape as above under a degenerate transform
+        ("M1,1 L2,1 L2,2 L1,2 Z", Affine2D.degenerate(), "M0,0",),
+    ],
+)
+def test_apply_basic_transform(path, transform, expected_result):
+    actual = SVGPath(d=path).apply_transform(transform).d
+    print(f"A: {actual}")
+    print(f"E: {expected_result}")
+    assert actual == expected_result
+
+
+@pytest.mark.parametrize(
+    "path, expected_result",
+    [
+        (SVGRect(width=1, height=1), True),
+        # we see paths with move and nothing else in the wild
+        (SVGPath(d="M1,2"), False),
+        (SVGPath(d="M1,2 M3,4"), False),
+        (SVGPath(d="M1,2 L3,4 Z"), True),
+    ],
+)
+def test_might_paint(path, expected_result):
+    assert path.might_paint() == expected_result, path
